@@ -13,13 +13,11 @@ if __name__ == '__main__':
         print("inactive")
 
     rel = RelayClient(bus, "relay")
-    rel.on_active(active)
-    rel.on_inactive(inactive)
 
     while True:
-        rel.closed = False
+        rel.active = False
         sleep(1)
-        print("open: ", rel.closed)
-        rel.closed = True
+        print("open: ", rel.active)
+        rel.active = True
         sleep(1)
-        print("closed: ", rel.closed)
+        print("closed: ", rel.active)
